package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcProcureApproval;

/**
 * 采购审批Service接口
 * 
 * @author cmc
 * @date 2024-09-18
 */
public interface ICmcProcureApprovalService 
{
    /**
     * 查询采购审批
     * 
     * @param procureApplyId 采购审批主键
     * @return 采购审批
     */
    public CmcProcureApproval selectCmcProcureApprovalByProcureApplyId(String procureApplyId);

    /**
     * 查询采购审批列表
     * 
     * @param cmcProcureApproval 采购审批
     * @return 采购审批集合
     */
    public List<CmcProcureApproval> selectCmcProcureApprovalList(CmcProcureApproval cmcProcureApproval);

    /**
     * 新增采购审批
     * 
     * @param cmcProcureApproval 采购审批
     * @return 结果
     */
    public int insertCmcProcureApproval(CmcProcureApproval cmcProcureApproval);

    /**
     * 修改采购审批
     * 
     * @param cmcProcureApproval 采购审批
     * @return 结果
     */
    public int updateCmcProcureApproval(CmcProcureApproval cmcProcureApproval);

    /**
     * 批量删除采购审批
     * 
     * @param procureApplyIds 需要删除的采购审批主键集合
     * @return 结果
     */
    public int deleteCmcProcureApprovalByProcureApplyIds(String[] procureApplyIds);

    /**
     * 删除采购审批信息
     * 
     * @param procureApplyId 采购审批主键
     * @return 结果
     */
    public int deleteCmcProcureApprovalByProcureApplyId(String procureApplyId);
}
